@@ -1,17 +1,14 @@
-# coding=utf-8
-
 import json
 import platform
 import re
 import ssl
-import warnings
 from collections import OrderedDict
+from urllib.parse import urlencode
 
 import requests
 from requests_oauthlib import OAuth2Session
 
-from .compat import urlencode
-from .error import RemovedIn23Warning, RequestError, RequestSetupError
+from .error import RequestError, RequestSetupError
 from .resources.captures import Captures
 from .resources.chargebacks import Chargebacks
 from .resources.customer_mandates import CustomerMandates
@@ -74,7 +71,7 @@ class Client(object):
                     access_token=access_token))
         return access_token
 
-    def __init__(self, api_key=None, api_endpoint=None, timeout=10):
+    def __init__(self, api_endpoint=None, timeout=10):
         self.api_endpoint = self.validate_api_endpoint(api_endpoint or self.API_ENDPOINT)
         self.api_version = self.API_VERSION
         self.timeout = timeout
@@ -122,15 +119,6 @@ class Client(object):
         self.set_user_agent_component('OpenSSL', ssl.OPENSSL_VERSION.split(' ')[1],
                                       sanitize=False)  # keep legacy formatting of this component
 
-        if api_key:
-            # There is no clean way for supporting both API key and access token acceptance and validation
-            #  in __init__(). Furthermore the naming of the parameter would be inconsistent.
-            # Using class methods is way cleaner.
-            msg = "Setting the API key during init will be removed in the future. " \
-                  "Use Client.set_api_key() or Client.set_access_token() instead."
-            warnings.warn(msg, RemovedIn23Warning)
-            self.api_key = self.validate_api_key(api_key)
-
     def set_api_endpoint(self, api_endpoint):
         self.api_endpoint = self.validate_api_endpoint(api_endpoint)
 
